@@ -39,6 +39,8 @@ client_authenticate (Gsasl * ctx, Gsasl_session * session)
     {
       printf ("Input base64 encoded data from server:\n");
       fgets (buf, sizeof (buf) - 1, stdin);
+      if (buf[strlen (buf) - 1] == '\n')
+	buf[strlen (buf) - 1] = '\0';
 
       rc = gsasl_step64 (session, buf, &p);
 
