@@ -227,8 +227,8 @@ gsasl_strerror (int err)
 	    "host name was not provided.");
       break;
 
-    case GSASL_UNICODE_NORMALIZATION_ERROR:
-      p = _("Failed to perform Unicode Normalization on string.");
+    case GSASL_SASLPREP_ERROR:
+      p = _("Could not prepare internationalized (non-ASCII) string.");
       break;
 
 #ifndef GSASL_NO_OBSOLETE
@@ -356,6 +356,10 @@ gsasl_strerror (int err)
       p = _("SASL mechanism needs gsasl_server_callback_retrieve() "
 	    "callback (application error)");
       break;
+
+    case GSASL_UNICODE_NORMALIZATION_ERROR:
+      p = _("Failed to perform Unicode Normalization on string.");
+      break;
 #endif
 
     default:
