@@ -51,7 +51,8 @@ enum
   GSASL_NEED_SERVER_SECURID_CALLBACK = 24,
   GSASL_NEED_SERVER_SERVICE_CALLBACK = 25,
   GSASL_NEED_SERVER_GSSAPI_CALLBACK = 26,
-  GSASL_NEED_SERVER_RETRIEVE_CALLBACK = 27
+  GSASL_NEED_SERVER_RETRIEVE_CALLBACK = 27,
+  GSASL_UNICODE_NORMALIZATION_ERROR = 28
 } __attribute__ ((deprecated));
 
 typedef Gsasl Gsasl_ctx __attribute__ ((deprecated));
@@ -126,6 +127,13 @@ extern int gsasl_base64_decode (char const *src,
 				char *target, size_t targsize)
   __attribute__ ((deprecated));
 
+extern char *gsasl_stringprep_nfkc (const char *in, ssize_t len)
+  __attribute__ ((deprecated));
+extern char *gsasl_stringprep_saslprep (const char *in, int *stringprep_rc)
+  __attribute__ ((deprecated));
+extern char *gsasl_stringprep_trace (const char *in, int *stringprep_rc)
+  __attribute__ ((deprecated));
+
 /* Callback prototypes */
 typedef int (*Gsasl_client_callback_anonymous) (Gsasl_session * sctx,
 						char *out, size_t * outlen);
