@@ -38,7 +38,7 @@ extern "C"
    * Used together with stringprep_check_version() to verify header file
    * and run-time library consistency.
    */
-# define GSASL_VERSION "0.2.2"
+# define GSASL_VERSION "0.2.3"
 
   /* RFC 2222: SASL mechanisms are named by strings, from 1 to 20
    * characters in length, consisting of upper-case letters, digits,
@@ -64,7 +64,6 @@ extern "C"
     GSASL_MALLOC_ERROR = 7,
     GSASL_BASE64_ERROR = 8,
     GSASL_CRYPTO_ERROR = 9,
-    GSASL_UNICODE_NORMALIZATION_ERROR = 28,
     GSASL_SASLPREP_ERROR = 29,
     GSASL_MECHANISM_PARSE_ERROR = 30,
     GSASL_AUTHENTICATION_ERROR = 31,
@@ -82,7 +81,6 @@ extern "C"
     GSASL_NO_PIN = 57,
     GSASL_NO_SERVICE = 58,
     GSASL_NO_HOSTNAME = 59,
-    GSASL_CANNOT_VALIDATE = 60,
     /* Mechanism specific errors. */
     GSASL_GSSAPI_RELEASE_BUFFER_ERROR = 37,
     GSASL_GSSAPI_IMPORT_NAME_ERROR = 38,
@@ -119,6 +117,12 @@ extern "C"
     GSASL_CIPHER_AES = 32
   } Gsasl_cipher;
 
+  /* SASLprep flags, see gsasl_saslprep(). */
+  typedef enum
+    {
+      GSASL_ALLOW_UNASSIGNED = 1
+    } Gsasl_saslprep_flags;
+
   /* Library handles */
   typedef struct Gsasl Gsasl;
   typedef struct Gsasl_session Gsasl_session;
@@ -137,6 +141,7 @@ extern "C"
     GSASL_PASSCODE = 8,
     GSASL_SUGGESTED_PIN = 9,
     GSASL_PIN = 10,
+    GSASL_REALM = 11,
     /* Server validation callback properties. */
     GSASL_VALIDATE_SIMPLE = 500,
     GSASL_VALIDATE_EXTERNAL = 501,
@@ -227,9 +232,8 @@ extern "C"
   extern const char *gsasl_strerror (int err);
 
   /* Internationalized string processing: stringprep.c */
-  extern char *gsasl_stringprep_nfkc (const char *in, ssize_t len);
-  extern char *gsasl_stringprep_saslprep (const char *in, int *stringprep_rc);
-  extern char *gsasl_stringprep_trace (const char *in, int *stringprep_rc);
+  extern int gsasl_saslprep (const char *in, Gsasl_saslprep_flags flags,
+			     char **out, int *stringpreprc);
 
   /* Utilities: base64.c, md5pwd.c, crypto.c */
   extern int gsasl_base64_to (const char *in, size_t inlen,
