@@ -23,13 +23,6 @@
 # include "config.h"
 #endif
 
-/* FIXME. We need the library config.h too. */
-#undef PACKAGE
-#undef PACKAGE_NAME
-#undef PACKAGE_STRING
-#undef PACKAGE_TARNAME
-#include "lib/config.h"
-
 #include <stdio.h>
 #include <stdarg.h>
 #include <stdlib.h>
@@ -63,17 +56,12 @@ struct sasltv
   int securidrc;
 };
 static struct sasltv sasltv[] = {
-#ifdef USE_EXTERNAL
   {CLIENT, "EXTERNAL", {"", NULL}},
   {SERVER, "EXTERNAL", {"", NULL}},
-#endif
-#ifdef USE_ANONYMOUS
   {CLIENT, "ANONYMOUS", {"", "Zm9vQGJhci5jb20=", NULL, NULL}, NULL, NULL,
    NULL, NULL, NULL, NULL, "foo@bar.com"},
   {SERVER, "ANONYMOUS", {"Zm9vQGJhci5jb20=", NULL, NULL}, NULL, NULL, NULL,
    NULL, NULL, NULL, "foo@bar.com"},
-#endif
-#ifdef USE_NTLM
   {CLIENT, "NTLM",
    {"Kw==", "TlRMTVNTUAABAAAAB7IAAAYABgAgAAAAAAAAACYAAABhdXRoaWQ=",
     "TlRMTVNTUAAAAAAAAAAAAAAAAAAAAGFiY2RlZmdoMDEyMzQ1Njc4ODY2NDQwMTIz",
@@ -81,47 +69,35 @@ static struct sasltv sasltv[] = {
     "AAAAACIAAAAAABhYmEAdQB0AGgAaQBkAGEAdQB0AGgAaQBkABeBBp9xJad9eYo3oh1k55"
     "GNFDIui8H8Qz4CfWYVVToBhVzFFbzyzqAZN5Wl59K/Fg==",
     NULL, NULL}, "password", "authzid", "authid"},
-#endif
-#ifdef USE_PLAIN
   {CLIENT, "PLAIN",
    {"", "YXV0aHppZABhdXRoaWQAcGFzc3dvcmQ=", NULL, NULL}, "password",
    "authzid", "authid"},
   {CLIENT, "PLAIN",
    {"", "YQBhAGE=", NULL, NULL}, "a", "a", "a"},
-#ifdef WITH_STRINGPREP
   {CLIENT, "PLAIN",
-   {"", "YQBhAGE=", NULL, NULL}, UTF8_a, UTF8_a, UTF8_a},
-#endif
+   {"", "wqoAwqoAwqo=", NULL, NULL}, UTF8_a, UTF8_a, UTF8_a},
   {SERVER, "PLAIN",
    {"YXV0aHppZABhdXRoaWQAcGFzc3dvcmQ=", NULL, NULL}, "password", "authzid",
    "authid"},
   {SERVER, "PLAIN",
    {"", "", "YXV0aHppZABhdXRoaWQAcGFzc3dvcmQ=", NULL, NULL}, "password",
    "authzid", "authid"},
-#endif
-#ifdef USE_LOGIN
   {CLIENT, "LOGIN",
-   {"VXNlciBOYW1l", "YXV0aHppZA==", "UGFzc3dvcmQ=", "cGFzc3dvcmQ=", NULL,
-    NULL}, "password", "authzid", "authid"},
+   {"VXNlciBOYW1l", "YXV0aGlk", "UGFzc3dvcmQ=", "cGFzc3dvcmQ=", NULL,
+    NULL}, "password", NULL, "authid"},
   {CLIENT, "LOGIN",
-   {"VXNlciBOYW1l", "YQ==", "UGFzc3dvcmQ=", "YQ==", NULL, NULL}, "a", "a",
+   {"VXNlciBOYW1l", "YXV0aGlk", "UGFzc3dvcmQ=", "YQ==", NULL, NULL}, "a", NULL,
    "authid"},
-#ifdef WITH_STRINGPREP
   {CLIENT, "LOGIN",
-   {"VXNlciBOYW1l", "YQ==", "UGFzc3dvcmQ=", "YQ==", NULL, NULL}, UTF8_a,
-   UTF8_a, "authid"},
-#endif
+   {"VXNlciBOYW1l", "YXV0aGlk", "UGFzc3dvcmQ=", "wqo=", NULL, NULL}, UTF8_a,
+   NULL, "authid"},
   {SERVER, "LOGIN",
-   {"", "VXNlciBOYW1l", "YXV0aHppZA==", "UGFzc3dvcmQ=", "cGFzc3dvcmQ=",
-    NULL, NULL}, "password", "authzid", "authid"},
-#endif
-#ifdef USE_CRAM_MD5
+   {"", "VXNlciBOYW1l", "YXV0aGlk", "UGFzc3dvcmQ=", "cGFzc3dvcmQ=",
+    NULL, NULL}, "password", NULL, "authid"},
   {CLIENT, "CRAM-MD5",
    {"PGNiNmQ5YTQ5ZDA3ZjEwY2MubGliZ3Nhc2xAbG9jYWxob3N0Pg==",
     "YXV0aGlkIGZkNjRmMjYxZWYxYjBjYjg0ZmZjNGVmYzgwZDk3NjFj", NULL, NULL},
    "password", "authzid", "authid"},
-#endif
-#ifdef USE_SECURID
   {CLIENT, "SECURID",
    {"", "YXV0aHppZABhdXRoaWQANDcxMQA=", NULL, NULL}, NULL, "authzid",
    "authid", NULL, NULL, NULL, NULL, "4711"},
@@ -163,7 +139,6 @@ static struct sasltv sasltv[] = {
     "YXV0aHppZABhdXRoaWQANDcxMQA=", NULL, NULL}, NULL, "authzid", "authid",
    NULL, NULL, NULL, NULL, "4711", NULL, NULL,
    GSASL_SECURID_SERVER_NEED_ADDITIONAL_PASSCODE}
-#endif
 };
 
 static int
@@ -463,19 +438,17 @@ doit (void)
     {
       gsasl_application_data_set (ctx, &i);
 
-#if !USE_CLIENT
-      if (sasltv[i].clientp)
-	continue;
-#endif
-#if !USE_SERVER
-      if (!sasltv[i].clientp)
-	continue;
-#endif
-
       if (debug)
 	printf ("Entry %d %s mechanism %s:\n",
 		i, sasltv[i].clientp ? "client" : "server", sasltv[i].mech);
 
+      if (sasltv[i].clientp)
+	res = gsasl_client_support_p (ctx, sasltv[i].mech);
+      else
+	res = gsasl_server_support_p (ctx, sasltv[i].mech);
+      if (!res)
+	continue;
+
       if (sasltv[i].clientp)
 	res = gsasl_client_start (ctx, sasltv[i].mech, &xctx);
       else
@@ -536,6 +509,9 @@ doit (void)
 	      j = -1;
 	      break;
 	    }
+
+	  if (strcmp (sasltv[i].mech, "SECURID") != 0 && res == GSASL_OK)
+	    break;
 	}
 
       if ((int) j != -1 && res == GSASL_OK && sasltv[i].step[j + 2])
